<template>
  <el-form :model="form" label-width="80px" class="terrain-settings">
    <el-form-item label="大小">
      <el-slider :step="0.1" v-model="form.rainSize" :min="0" :max="1"></el-slider>
    </el-form-item>
    <el-form-item label="密度:">
      <el-slider :step="10" :min="10" :max="200" v-model="form.rainDensity">
      </el-slider>
    </el-form-item>
    <el-form-item label="速度">
      <el-slider v-model="form.rainSpeed" :min="0" :max="150"></el-slider>
    </el-form-item>
    <el-form-item label="颜色">
      <el-color-picker v-model="form.rainColor" />
    </el-form-item>
  </el-form>
</template>

<script setup>
import { reactive, watch } from "vue";
const form = reactive({
  rainSize: 0.5,
  rainSpeed: 50,
  rainDensity: 30,
  rainColor: "#99B3CC",
});

// 定义 props 和 emit
const props = defineProps({
  modelValue: {
    type: Object,
    default: () => ({}),
  },
});
const emit = defineEmits(["update-rain"]);

// 监听 form 的变化，并将最新值传递给父组件
watch(
  () => ({ ...form }), // 深拷贝以确保响应式触发
  (newVal) => {
    emit("update-rain", newVal);
  },
  { deep: true } // 深度监听
);
</script>
<style lang="less" scoped>
.terrain-settings {
  padding: 20px;
  width: 290px;
  background: url("@/assets/img/tools/plotting_new.png") no-repeat;
  filter: opacity(83%);
  background-size: 100% 100%;
  box-sizing: border-box;
}
</style>
